//[mahjong-utils](../../index.md)/[mahjongutils.models](index.md)/[isSangen](is-sangen.md)

# isSangen

[common]\
val [Tile](-tile/index.md).[isSangen](is-sangen.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否为三元牌
